Module: DataModeler::Model
- Defined in:
- lib/data_modeler/model.rb
Overview
All models for the framework should belong to this module. Also includes a model selector for initialization from config.
Defined Under Namespace
Classes: FANN
Class Method Summary collapse
-
.from_conf(type:, **opts) ⇒ Model
Returns a new Model correctly initialized based on the
typeof choice.
Class Method Details
.from_conf(type:, **opts) ⇒ Model
Returns a new Model correctly initialized based on the type of choice
10 11 12 13 14 15 16 |
# File 'lib/data_modeler/model.rb', line 10 def self.from_conf type:, **opts case type when :fann FANN.new opts else abort "Unrecognized model: #{type}" end end |